@@ -97,7 +97,10 @@ class MultiScaleDiscriminator(nn.Module):
         return out, intermediates
 
 class ModReLU(nn.Module):
-    """ https://arxiv.org/abs/2102.13092 """
+    """
+    https://arxiv.org/abs/1705.09792
+    https://github.com/pytorch/pytorch/issues/47052#issuecomment-718948801
+    """
     def __init__(self):
         super().__init__()
         self.b = nn.Parameter(torch.tensor(0.))
